@@ -5,11 +5,8 @@ from pulse_ssz.sedes.basic import BasicSedes
 
 
 class String(BasicSedes[str, str]):
-    def __init__(self, num_bits: int) -> None:
-        if num_bits % 8 != 0:
-            raise ValueError("Number of bits must be a multiple of 8")
-        self.num_bits = num_bits
-        super().__init__(num_bits // 8)
+    def __init__(self) -> None:
+        super().__init__(size=1)
 
     def serialize(self, v: str) -> bytes:
         value = int(v, 10)
@@ -19,26 +16,26 @@ class String(BasicSedes[str, str]):
             )
 
         try:
-            return value.to_bytes(self.size, "little")
+            return value.to_bytes(16, "little")
         except OverflowError:
             raise SerializationError(
-                f"{value} is too large to be serialized in {self.size * 8} bits"
+                f"{value} is too large to be serialized in {16} bits"
             )
 
     def deserialize(self, data: bytes) -> str:
         if len(data) != self.size:
             raise DeserializationError(
-                f"Cannot deserialize length {len(data)} byte-string as str{self.size*8}"
+                f"Cannot deserialize length {len(data)} byte-string as str{16}"
             )
         return str(int.from_bytes(data, "little"))
 
     def get_sedes_id(self) -> str:
-        return f"{self.__class__.__name__}{self.num_bits}"
+        return self.__class__.__name__
 
     def __hash__(self) -> int:
-        return hash((hash(String), self.num_bits))
+        return hash((hash(String),))
 
     def __eq__(self, other: Any) -> bool:
-        return isinstance(other, String) and other.num_bits == self.num_bits
+        return isinstance(other, String)
 
-string = String(16)
\ No newline at end of file
+string = String()
\ No newline at end of file
